@@ -1,4 +1,4 @@
-import logging,threading,os,shutil,requests,asyncio,time,subprocess
+import threading,os,shutil,requests,asyncio,time,subprocess
 from .json_utils import (unified_json_loader,
                          find_keys,safe_write_to_json,
                          safe_read_from_json,
@@ -43,7 +43,10 @@ from .type_utils import (make_bool,
                          T_or_F_obj_eq,
                          is_number,
                          makeInt,
-                         str_lower)
+                         str_lower,
+                         confirm_type,
+                         get_all_types,
+                         get_media_types)
 from .math_utils import (convert_to_percentage,
                          exponential,
                          get_percentage,
@@ -60,4 +63,5 @@ from .abstract_classes import *
 from .parse_utils import (num_tokens_from_string,
                           chunk_source_code,
                           chunk_any_to_tokens)
-from .log_utils import get_logFile,AbstractLogManager
+
+from .log_utils import get_logFile
