@@ -56,7 +56,48 @@ Author: putkoff
 Date: 05/31/2023
 Version: 0.1.2
 """
+import os
 from typing import Union
+from .path_utils import get_all_item_paths
+def get_all_key_values(keys=None,dict_obj=None):
+    keys = keys or []
+    dict_obj = dict_obj or {}
+    new_dict_obj = {}
+    for key in keys:
+        values = dict_obj.get(key)
+        if values:
+            new_dict_obj[key]=values
+    return new_dict_obj
+def get_media_types(types=None):
+    types = types or []
+    media_types = {
+        'image': {'.jpg', '.jpeg', '.png', '.gif', '.bmp', '.tiff', '.webp', '.svg'},
+        'video': {'.mp4', '.avi', '.mov', '.wmv', '.flv', '.mkv', '.webm'},
+        'audio': {'.mp3', '.wav', '.ogg', '.flac', '.aac', '.m4a'},
+        'document': {'.pdf', '.doc', '.docx', '.txt', '.rtf'},
+        'presentation': {'.ppt', '.pptx'},
+        'spreadsheet': {'.xls', '.xlsx', '.csv'}
+    }
+    if types:
+        return get_all_key_values(keys=types,dict_obj=media_types)
+    return media_types
+def confirm_type(file_path,media_types=None):
+    media_types = media_types or get_media_types()
+    dirname = os.path.dirname(file_path)
+    basename = os.path.basename(file_path)
+    filename,ext = os.path.splitext(basename)
+    for typ,exts in media_types.items():
+         if ext in exts:
+             return typ
+    
+def get_all_types(types=None,directory=None):
+    types = types or []
+    if not directory or not os.path.isdir(directory):
+        return []
+    item_paths = get_all_item_paths(directory)
+    media_types = get_media_types(types=types)
+    item_paths = [item_path for item_path in item_paths if confirm_type(item_path,media_types=media_types)]
+    return item_paths    
 def is_iterable(obj:any):
     try:
         iterator=iter(obj)
